#[non_exhaustive]pub struct PlanOptions {
pub strip_rows: u32,
pub square_size: u32,
}Expand description
Knobs for Plan::build.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.strip_rows: u32Rows per strip in sequential segments.
square_size: u32Edge length of square tiles in spatial segments.
Implementations
Sourceimpl PlanOptions
impl PlanOptions
Sourcepub const fn with_strip_rows(self, rows: u32) -> Self
pub const fn with_strip_rows(self, rows: u32) -> Self
Set the rows per strip in sequential segments.
PlanOptions is #[non_exhaustive], so downstream crates cannot use a
struct literal; these setters are the only way to configure it.
Sourcepub const fn with_square_size(self, size: u32) -> Self
pub const fn with_square_size(self, size: u32) -> Self
Set the edge length of square tiles in spatial segments.